#!/usr/bin/env python
import iam_sympy_example

import sympy
e=sympy.Rational(2)**50/sympy.Rational(10)**50
print e
